@@ -34,6 +34,11 @@ getOptStateTasks = function(opt.state) {
   tasks
 }
 
+getOptStateDesigns = function(opt.state) {
+  tasks = getOptStateTasks(opt.state)
+  lapply(tasks, getTaskData)
+}
+
 getOptStateTimeModel = function(opt.state) {
   opt.path = getOptStateOptPath(opt.state)
   time.model = opt.state$time.model
@@ -119,6 +124,7 @@ getOptStateState = function(opt.state) {
 
 getOptStateTermination = function(opt.state) {
   terminate = shouldTerminate.OptState(opt.state)
+  setOptStateProgress(opt.state, terminate$progress)
   # update only if termination condition is met
   if (terminate$term) {
     setOptStateState(opt.state, terminate$code)
@@ -126,6 +132,10 @@ getOptStateTermination = function(opt.state) {
   terminate
 }
 
+getOptStateProgress = function(opt.state) {
+  opt.state$progress
+}
+
 getOptStateValidStates = function() {
   c("init", "iter", getOptStateValidTerminationStates())
 }
@@ -133,3 +143,4 @@ getOptStateValidStates = function() {
 getOptStateValidTerminationStates = function() {
   c("term.iter", "term.time", "term.exectime", "term.yval", "term.feval", "term.custom")
 }
+
