@@ -12,7 +12,7 @@
 #' Please note the following things:
 #' - The true objective function (and later everything which is predicted from our surrogate model)
 #'   is evaluated on a regular spaced grid. These evaluations are stored in the result object.
-#'   You can control the resultion of this grid via \code{points.per.dim}.
+#'   You can control the resolution of this grid via \code{points.per.dim}.
 #'   Parallelization of these evaluations is possible with the R package parallelMap on the level \code{mlrMBO.feval}.
 #' - In every iteration the fitted, approximating surrogate model is stored in the result object
 #'   (via \code{store.model.at} in \code{control}) so we can later visualize it quickly.
@@ -40,7 +40,7 @@ exampleRun = function(fun, design = NULL, learner = NULL, control,
   noisy = isNoisy(fun)
   control$noisy = noisy
   control$minimize = shouldBeMinimized(fun)
-  learner = checkLearner(learner, par.set, control, fun)
+  learner = checkLearner(learner, control, fun)
   assertClass(control, "MBOControl")
   points.per.dim = asCount(points.per.dim, positive = TRUE)
   noisy.evals = asCount(noisy.evals, positive = TRUE)
