@@ -1,3 +1,8 @@
+#' @title Propose candidates for the objective function
+#' @description Propose points for the objective function that should be evaluated according to the infill criterion and the recent evaluations.
+#'
+#' @param opt.state [\code{\link{OptState}}]
+#' @export
 # Propose infill points - simple dispatcher to real methods
 #
 # input:
@@ -11,7 +16,7 @@
 #   errors.models [character] : model errors, resulting in randomly proposed points.
 #                               length is one string PER PROPOSED POINT, not per element of <models>
 #                               NA if the model was Ok, or the (first) error message if some model crashed
-proposePoints.OptState = function(opt.state) {
+proposePoints = function(opt.state) {
   opt.problem = getOptStateOptProblem(opt.state)
   control = getOptProblemControl(opt.problem)
 
